# sinnn
 Sohiab Imran's Numpy Neural Network.\
 sinnn is a numpy powered low code neural network library. 
 
 
 Work in progress 🔨 .
 To do:
 1) Add Regularisation
 2) Add more Initialisers
 3) Add more Optimisers

 
# Installation

pip install sinnn

Requirements:
    Numpy
    
# Features
Support for a limited number of features is available as the library is still new.
Supported features are:\
Layers: Dense, ReLU\
Initialisers: Zeros, SmallRandom\
Losses: MSE, CrossEntropy\
Metrics: loss, accuracy \
Optimisers: SGD, Momentum, AdaGrad\
utils: sigmoid, softmax, one_hot, batches, save_model, load_model
        
    
# Examples
Please refer to the examples directory for example deep learning problems solved using sinnn.